@@ -5,8 +5,6 @@
 #' @param turl like <https://news.naver.com/main/read.nhn?mode=LSD&mid=shm&sid1=100&oid=056&aid=0010335895>.
 #' @return Get character url.
 #' @export
-#' @importFrom rvest html_nodes html_attr html_text
-#' @importFrom httr GET content add_headers user_agent
 #' @examples
 #'  \donttest{
 #'   print(video_url_ex)
@@ -14,6 +12,30 @@
 #'   }
 
 getVideoUrl <- function(turl = url) {
+
+  ulist <- getVideoInfo(turl)
+  tarv <- ulist$videos$list[[1]]$source
+  return(tarv)
+
+}
+
+getVideoSubtitleUrl <- function(turl = url) {
+
+  ulist <- getVideoInfo(turl)
+  tars <- ulist$captions$list[[1]]$source
+  return(tars)
+
+}
+
+# getVideoSubtitleUrl("https://news.naver.com/main/read.nhn?mode=LSD&mid=tvh&oid=052&aid=0001385191&sid1=293") %>%
+#   GET() %>%
+#   content() %>%
+#   rawToChar() %>%
+#   {Encoding(.)<-"UTF-8";.}
+
+#' @importFrom rvest html_nodes html_attr html_text
+#' @importFrom httr GET content add_headers user_agent
+getVideoInfo <- function(turl = url){
   uat <-
     httr::user_agent("N2H4 by chanyub.park <mrchypark@gmail.com>")
   src <- httr::GET(turl, uat)
@@ -41,8 +63,5 @@ getVideoUrl <- function(turl = url) {
            key)
   tem   <- httr::GET(url, uat)
   ulist <- httr::content(tem, "parsed")
-
-  tarv <- ulist$videos$list[[1]]$source
-  return(tarv)
-
+  return(ulist)
 }
